import json
from jsonschema import validate
import notarize
from notarize.client import Client

from jsonschema import validate, Draft202012Validator
from jsonschema.exceptions import best_match, ValidationError

def get_base_url(env):
    return notarize.api_base

class ConfigTypeError(Exception):
    pass

class RequestBodyException(Exception):
    pass

class BaseResource:

    def __init__(self, params):
        try:
            config = params['config']
            self.apikey = config.apikey
            self.version = config.version
        except AttributeError:
            raise ConfigTypeError('config must be of type notarize.config.Config')

        self.base_url = get_base_url('prod')

    def _make_client_request(self, request_type, endpoint, payload=None, request_validator=None):
        if request_validator:
            errors = self._validate_request_body(request_validator, payload)

        body = json.dumps(payload or {})
        client = Client(base_url=self.base_url, api_key=self.apikey)

        if request_type == 'get':
            if payload is None:
                response = client.get(endpoint)
            else:
                response = client.get(endpoint, params=body)
        elif request_type == 'post':
            response = client.post(endpoint, body=body)
        elif request_type == 'put':
            response = client.put(endpoint, body=body)
        elif request_type == 'patch':
            response = client.patch(endpoint, body=body)
        elif request_type == 'delete':
            response = client.delete(endpoint, body=body)
        else:
            raise ValueError(f'Unhandled request_type "{request_type}"')
        return response

    def _validate_request_body(self, request_validator, body):
        """ returns best match error for request """
        try:
            validate(instance=body, schema=request_validator)
        except ValidationError as e:
            message = best_match(Draft202012Validator(request_validator).iter_errors(body)).message
            raise RequestBodyException(f'Request body has error: {message}')

    def _validate_response(self, response):
        return response

    def validate_response(self, response):
        raise NotImplementedError('Need to have a validate response for client')

