from .base_resource import BaseResource
from typing import Optional, Dict
from jsonschema import validate

from notarize.api_resources.validators import Document, Transaction
from notarize.api_resources.base_resource import BaseResource

class BusinessTransaction(BaseResource):

    def __init__(self, **kwargs):
        self.id = kwargs.get('id')
        super().__init__(kwargs)

    def create(self, payload):
        endpoint = '/v1/transactions'
        response = self._make_client_request('post', endpoint, payload=payload, request_validator= Transaction.schema())
        return self.validate_response(response)

    def update(self, payload):
        endpoint = '/v1/transactions/' + self.id
        response = self._make_client_request('put', endpoint, payload=payload)
        return self.validate_response(response)

    def list(self):
        endpoint = '/v1/transactions'
        response = self._make_client_request('get', endpoint)
        return self.validate_response(response)

    def retrieve(self):
        endpoint = '/v1/transactions/' + self.id
        response = self._make_client_request('get', endpoint)
        return self.validate_response(response)

    def activate(self, payload):
        endpoint = '/v1/transactions/' + self.id + '/notarization_ready'
        response = self._make_client_request('post', endpoint, payload=payload)
        return self.validate_response(response)

    def delete(self):
        endpoint = '/v1/transactions/' + self.id
        response = self._make_client_request('delete', endpoint)
        return self.validate_response(response)

    def validate_response(self, response):
        return self._validate_response(response)

    def add_document(self, payload):
        endpoint = '/v1/transactions/' + str(self.id) + "/documents"
        response = self._make_client_request('post', endpoint=endpoint, payload=payload, request_validator=Document.schema())
        return response
