from pydantic import BaseModel, Field

from typing import List, Optional, Dict

class SignerDesignation(BaseModel):
    signer_identifier: Optional[str]
    type: Optional[str]
    page_number: Optional[int]
    x: Optional[int]
    y: Optional[int]
    height: Optional[int]
    width: Optional[int]
    hint: Optional[str]
    signer_designation: Optional[str]

class SignerDesignationGroup(BaseModel):
    name: str
    min_required: str
    max_required: str

class Document(BaseModel):
    requirement: str
    resource: str
    filename: Optional[str]
    customer_can_annotate: Optional[bool]
    witness_required: Optional[bool]
    pdf_bookmarked: Optional[bool]
    tracking_id: Optional[str]
    text_tag_syntax: Optional[str]
    signing_designations: Optional[List[SignerDesignation]]
    signing_designations: Optional[List[SignerDesignationGroup]]

class Address(BaseModel):
    line1: str
    line2: str
    city: str
    state: str
    postal: str
    country: str


class Signer(BaseModel):
    email: str
    first_name: Optional[str]
    middle_name: Optional[str]
    last_name: Optional[str]
    phone_number: Optional[str]
    address: Optional[Address]

class NotaryInstruction(BaseModel):
    notary_note: str

class Transaction(BaseModel):
    documents: Optional[List[Document]]
    signers: Optional[List[Signer]]
    external_id: Optional[str]
    entity: Optional[str]
    capacity: Optional[str]
    draft: Optional[bool]
    transaction_type: Optional[str]
    transaction_name: Optional[str]
    suppress_email: Optional[bool]
    message_to_signer: Optional[str]
    message_signature: Optional[str]
    message_subject: Optional[str]
    require_new_signer_verification: Optional[bool]
    require_secondary_photo_id: Optional[bool]
    notary_instructions: Optional[NotaryInstruction]
    notary_id: Optional[str]
    notary_meeting_time: Optional[str]
    organization_id: Optional[str]
    activation_time: Optional[str]
    expiry: Optional[str]


