from .base_resource import BaseResource


def _validate_response(method):
    def new_method(*args, **kwargs):
        # TODO: Perform validation on this response?
        response = method(*args, **kwargs)
        return response

    return new_method


class Webhook(BaseResource):

    def __init__(self, type_, **kwargs):
        self.base_endpoint = '/mortgage/v1/webhooks' if type_ == 'real_estate' else '/v2/webhooks'
        super().__init__(kwargs)

    @_validate_response
    def retrieve_subscriptions(self):
        return self._make_client_request('get', self.base_endpoint)

    @_validate_response
    def retrieve_subscription_options(self):
        endpoint = f'{self.base_endpoint}/subscriptions'
        return self._make_client_request('get', endpoint)

    @_validate_response
    def get_subscription_info(self, webhook_id):
        endpoint = f'{self.base_endpoint}/{webhook_id}'
        return self._make_client_request('get', endpoint)

    @_validate_response
    def get_events_fired(self, webhook_id):
        endpoint = f'{self.base_endpoint}/{webhook_id}/events'
        return self._make_client_request('get', endpoint)

    @_validate_response
    def set_or_update_url(self, payload):
        return self._make_client_request('post', self.base_endpoint, payload=payload)

    @_validate_response
    def update_by_id(self, webhook_id, payload):
        endpoint = f'{self.base_endpoint}/{webhook_id}'
        return self._make_client_request('put', endpoint, payload=payload)

    @_validate_response
    def delete_url(self):
        return self._make_client_request('delete', self.base_endpoint)

    @_validate_response
    def delete_subscription(self, webhook_id):
        endpoint = f'{self.base_endpoint}/{webhook_id}'
        return self._make_client_request('delete', endpoint)
