from notarize.config import fetch_config

from notarize.api_resources.document import Document
from notarize.api_resources.business_transaction import BusinessTransaction

def retrieve_document(transaction_id, document_id):
    """
    Returns a document on a transaction. See https://dev.notarize.com/reference/get-document.

    Args:
        document_id (str): The ID of the document to fetch

    Returns:
        document (dict)
    """
    document = Document(config=fetch_config())
    return document.retrieve(transaction_id, document_id)


def update_document(document_id, params):
    """
    Update a document in a transaction that is still in the draft state.
    See https://dev.notarize.com/reference/update-business-documents.

    Args:
        document_id (str): The ID of the document to update
        params (dict[str, any]): The updated fields/values

    Returns:
        document (dict)
    """
    document = Document(config=fetch_config())
    return document.update(document_id, params)


def add_document(transaction_id, params):
    transaction = BusinessTransaction(config=fetch_config(), id=transaction_id)
    return transaction.add_document(params)
