from notarize.api_resources.notary import Notary
from notarize.config import fetch_config


def create_notary(params):
    """
    Method for creating a notary. See https://dev.notarize.com/reference/create-notary.

    Args:
        params (dict[str, any]): The params that will be passed to the create notary route

    Returns:
        response (dict[str, any])
    """
    notary = Notary(config=fetch_config())
    return notary.create(params)


def list_notaries(organization_id=None):
    """
    Returns details of all notaries associated with your account.
    See https://dev.notarize.com/reference/list-notaries.

    Args:
        organization_id (str): Optional, The organization ID for which to list notaries

    Returns:
        response (list[dict])
    """
    notary = Notary(config=fetch_config())
    return notary.list(organization_id)


def retrieve_notary(notary_id):
    """
    Returns details of a single notary in your account.
    See https://dev.notarize.com/reference/retrieve-notary.

    Args:
        notary_id (str): The ID of the notary to fetch

    Returns:
        response (dict)
    """
    notary = Notary(config=fetch_config())
    return notary.retrieve(notary_id)


def delete_notary(notary_id):
    """
    Removes a notary from your account. See https://dev.notarize.com/reference/delete-notary.

    Args:
        notary_id (str): The ID of the notary to delete

    Returns:
        response (dict)
    """
    notary = Notary(config=fetch_config())
    return notary.delete(notary_id)
