from notarize.api_resources.business_transaction import BusinessTransaction
from notarize.config import fetch_config


def create_transaction(params):
    """Method for creating a business transaction.
    See https://dev.notarize.com/reference/create-business-transaction

    Args:
        params (Dict[str, Any]): The params that will be passed to the create transaction route

    Returns:
        response (Dict[str, Any])
    """
    transaction = BusinessTransaction(config=fetch_config())
    response = transaction.create(params)
    return response


def update_transaction(transaction_id, params):
    transaction = BusinessTransaction(config=fetch_config(), id=transaction_id)
    return transaction.update(params)


def retrieve_transaction(transaction_id):
    """Method for retrieving a business transaction.
    See https://dev.notarize.com/reference/retrieve-business-transaction

    Args:
        transaction_id: (str): transaction_id denoting individual transaction to retrieve

    Returns:
        response (Dict[str, Any])
    """
    transaction = BusinessTransaction(config=fetch_config(), id=transaction_id)
    return transaction.retrieve()


def delete_transaction(transaction_id):
    transaction = BusinessTransaction(config=fetch_config(), id=transaction_id)
    return transaction.delete()

def activate_transaction(transaction_id, payload):
    transaction = BusinessTransaction(config=fetch_config(), id=transaction_id)
    return transaction.activate(payload)
