from notarize.api_resources.webhook import Webhook
from notarize.config import fetch_config


def set_webhook_url(params):
    """
    Set your webhook URL. See https://dev.notarize.com/reference/setupdate-webhook-url-v2.

    Args:
        params (dict[str, any]): The params that will be passed to the set webhook url route

    Returns:
        response (dict[str, any])
    """
    webhook = Webhook('business', config=fetch_config())
    return webhook.set_or_update_url(params)


def update_webhook_by_id(webhook_id, params):
    """
    Updates a specific webhook. See https://dev.notarize.com/reference/update-webhook-by-id.

    Args:
        webhook_id (str): The ID of the webhook to update

    Returns:
        response (dict[str, any])
    """
    webhook = Webhook('business', config=fetch_config())
    return webhook.update_by_id(webhook_id, params)


def retrieve_webhook_subscription_options():
    """
    Returns a list of all webhooks that are available to subscribe to.
    See https://dev.notarize.com/reference/retrieve-webhook-subscriptions.

    Args:
        None

    Returns:
        response (dict[str, any])
    """
    webhook = Webhook('business', config=fetch_config())
    return webhook.retrieve_subscription_options()


def retrieve_webhook_subscriptions():
    """
    Returns a list of all webhooks an organization is subscribed to.
    See https://dev.notarize.com/reference/retrieve-webhook-subscriptions-1.

    Args:
        None

    Returns:
        response (dict[str, any])
    """
    webhook = Webhook('business', config=fetch_config())
    return webhook.retrieve_subscriptions()


def get_webhook_events_fired(webhook_id):
    """
    Returns the events fired for a given webhook ID.
    See https://dev.notarize.com/reference/get-webhook-subscription-events-fired.

    Args:
        webhook_id (str): The ID of the webhook to get subscription events for

    Returns:
        response (dict[str, any])
    """
    webhook = Webhook('business', config=fetch_config())
    return webhook.get_events_fired(webhook_id)


def get_webhook_subscription_info(webhook_id):
    """
    Gets information about a webhook subscription.
    See https://dev.notarize.com/reference/get-webhook-subscription.

    Args:
        webhook_id (str): The ID of the webhook to get information for

    Returns:
        response (dict[str, any])
    """
    webhook = Webhook('business', config=fetch_config())
    return webhook.get_subscription_info(webhook_id)


def delete_webhook_subscription(webhook_id):
    """
    Deletes a webhook subscription.
    See https://dev.notarize.com/reference/delete-webhook-subscription.

    Args:
        webhook_id (str): The ID of the webhook to delete

    Returns:
        response (dict[str, any])
    """
    webhook = Webhook('business', config=fetch_config())
    return webhook.delete_subscription(webhook_id)
