import os
import json
from typing import Dict, Any

import requests


class Client:
    # Seconds
    TIMEOUT = 10

    def __init__(self, base_url, api_key):
        self.base_url = base_url
        self.api_key = api_key

    def get(self, endpoint: str, params: Dict[str, Any] = {}) -> Dict[str, Any]:
        path = os.path.join(self.base_url, endpoint.strip('/'))
        resp = requests.get(path, params=params, headers=self._headers, timeout=self.TIMEOUT)

        resp.raise_for_status()
        return resp.json()

    def post(self, endpoint, body={}, params={}):
        path = os.path.join(self.base_url, endpoint.strip('/'))
        return self._make_request('post', endpoint, body, params)

    def put(self, endpoint: str, body: Dict[str, Any]={}, params: Dict[str, Any]={}) -> Dict[str, Any]:
        path = os.path.join(self.base_url, endpoint.strip('/'))
        return self._make_request('put', endpoint, body, params)

    def patch(self, endpoint, body={}, params={}):
        return self._make_request('patch', endpoint, body, params)

    def delete(self, endpoint, body={}, params={}):
        return self._make_request('delete', endpoint, body, params)

    @property
    def _headers(self) -> Dict[str, Any]:
        return {
            'ApiKey': self.api_key,
            'Content-Type': 'application/json',
        }

    def _make_request(self, type_: str, endpoint: str, body: Dict[str, Any], params: Dict[str, Any]) -> Dict[str, Any]:
        path = os.path.join(self.base_url, endpoint.strip('/'))
        method = getattr(requests, type_)
        resp = method(path, data=body, params=params, headers=self._headers, timeout=self.TIMEOUT)

        resp.raise_for_status()
        return resp.json()
