from notarize.api_resources.real_estate_transaction import RealEstateTransaction
from notarize.config import fetch_config

def create_transaction(params):
    """Method for creating a real-estate transaction.
    See https://dev.notarize.com/reference/create-real-estate-transaction

    Args:
        params (Dict[str, Any]): The params that will be passed to the create transaction route

    Returns:
        response (Dict[str, Any])
    """
    transaction = RealEstateTransaction(config=fetch_config())
    response = transaction.create(params)
    return response

def get_transaction(transaction_id):
    """Method for retrieving a real-estate transaction.
    See https://dev.notarize.com/reference/retrieve-real-estate-transaction

    Args:
        transaction_id: (str): transaction_id denoting individual transaction to retrieve

    Returns:
        response (Dict[str, Any])
    """
    transaction = RealEstateTransaction(config=fetch_config(), id=transaction_id)
    return transaction.get()

def delete_transaction(transaction_id):
    transaction = RealEstateTransaction(config=fetch_config(), id=transaction_id)
    return transaction.delete()
